@@ -224,12 +224,12 @@ class GroupLightLevel(HueObject):
 
 
 class Group(HueObject):
-    def __init__(self, identity: str, uri: str) -> None:
-        self.state = GroupState("", uri)
-        self.action = GroupAction("", uri)
-        self.presence = GroupPresence("", uri)
-        self.lightlevel = GroupLightLevel("", uri)
-        super().__init__(identity, uri)
+    def __init__(self, identity: str, uri: str, raw: dict = None) -> None:
+        self.state = GroupState("", uri, raw=raw)
+        self.action = GroupAction("", uri, raw=raw)
+        self.presence = GroupPresence("", uri, raw=raw)
+        self.lightlevel = GroupLightLevel("", uri, raw=raw)
+        super().__init__(identity, uri, raw=raw)
 
     def load_data(self, raw: dict = None) -> None:
         super().load_data(raw)
